==> toolchain-2.3.0-0.tar.bz2: etc/conda/activate.d/toolchain_activate.sh <==
#!/bin/bash

if [ "$(uname)" == "Darwin" ]
then
    # for Mac OSX
    export CC=gcc
    export CXX=g++
    export MACOSX_VERSION_MIN="10.9"
    export MACOSX_DEPLOYMENT_TARGET="${MACOSX_VERSION_MIN}"
    export CMAKE_OSX_DEPLOYMENT_TARGET="${MACOSX_VERSION_MIN}"
    export CFLAGS="${CFLAGS} -mmacosx-version-min=${MACOSX_VERSION_MIN}"
    export CXXFLAGS="${CXXFLAGS} -mmacosx-version-min=${MACOSX_VERSION_MIN}"
    export LDFLAGS="${LDFLAGS} -headerpad_max_install_names"
    export LDFLAGS="${LDFLAGS} -mmacosx-version-min=${MACOSX_VERSION_MIN}"
    export LINKFLAGS="${LDFLAGS}"
    # tell boost not to cxx11 refrenes
    export CPPFLAGS="${CPPFLAGS} -DBOOST_NO_CXX11_RVALUE_REFERENCES"
    export CFLAGS="${CFLAGS} -stdlib=libstdc++"
    export CXXFLAGS="${CXXFLAGS} -stdlib=libstdc++"
    export LDFLAGS="${LDFLAGS} -stdlib=libstdc++"
elif [ "$(uname)" == "Linux" ]
then
    # for Linux
    export CC=gcc
    export CXX=g++
    export CFLAGS="${CFLAGS}"
    # Boost wants to enable `float128` support on Linux by default.
    # However, we don't install `libquadmath` so it will fail to find
    # the needed headers and fail to compile things. Adding this flag
    # tells Boost not to support `float128` and avoids this search
    # process. As it has confused a few people. We have added it here.
    # The idea to add this flag was inspired by this Boost ticked.
    #
    # https://svn.boost.org/trac/boost/ticket/9240
    #
    export CXXFLAGS="${CXXFLAGS} -DBOOST_MATH_DISABLE_FLOAT128"
    export LDFLAGS="${LDFLAGS}"
    export LINKFLAGS="${LDFLAGS}"
else
    echo "This system is unsupported by the toolchain."
    exit 1
fi

export CFLAGS="${CFLAGS} -m64"
export CXXFLAGS="${CXXFLAGS} -m64"

export CFLAGS="${CFLAGS} -D_GLIBCXX_USE_CXX11_ABI=0"
export CXXFLAGS="${CXXFLAGS} -D_GLIBCXX_USE_CXX11_ABI=0"

export CFLAGS="${CFLAGS} -O3 -g0 -DNDEBUG -mtune=native"
export CXXFLAGS="${CXXFLAGS} -O3 -g0 -DNDEBUG -mtune=native"

==> toolchain-2.4.0-0.tar.bz2: etc/conda/activate.d/toolchain_activate.sh <==
#!/bin/bash

if [[ "$(uname)" == "Darwin" ]]; then
    # for Mac OSX
    export CC=gcc
    export CXX=g++
    export MACOSX_VERSION_MIN="10.9"
    export MACOSX_DEPLOYMENT_TARGET="${MACOSX_VERSION_MIN}"
    export CMAKE_OSX_DEPLOYMENT_TARGET="${MACOSX_VERSION_MIN}"
    export CFLAGS="${CFLAGS} -mmacosx-version-min=${MACOSX_VERSION_MIN}"
    export CXXFLAGS="${CXXFLAGS} -mmacosx-version-min=${MACOSX_VERSION_MIN}"
    export LDFLAGS="${LDFLAGS} -headerpad_max_install_names"
    export LDFLAGS="${LDFLAGS} -mmacosx-version-min=${MACOSX_VERSION_MIN}"
    export LINKFLAGS="${LDFLAGS}"
    # tell boost not to cxx11 refrenes
    export CPPFLAGS="${CPPFLAGS} -DBOOST_NO_CXX11_RVALUE_REFERENCES"
    export CFLAGS="${CFLAGS} -stdlib=libstdc++"
    export CXXFLAGS="${CXXFLAGS} -stdlib=libstdc++"
    export LDFLAGS="${LDFLAGS} -stdlib=libstdc++"
elif [[ "$(uname)" == "Linux" ]]; then
    # for Linux
    export CC=gcc
    export CXX=g++
    export CFLAGS="${CFLAGS}"
    export LDFLAGS="${LDFLAGS}"
    export LINKFLAGS="${LDFLAGS}"
else
    echo "This system is unsupported by the toolchain."
    exit 1
fi

if [ -n "${CONDA_BUILD}" ]; then
  export CFLAGS="${CFLAGS} -m${ARCH}"
  export CXXFLAGS="${CXXFLAGS} -m${ARCH}"
fi

export CFLAGS="${CFLAGS} -D_GLIBCXX_USE_CXX11_ABI=0"
export CXXFLAGS="${CXXFLAGS} -D_GLIBCXX_USE_CXX11_ABI=0"

export CFLAGS="${CFLAGS} -O3 -g -DNDEBUG -mtune=native"
export CXXFLAGS="${CXXFLAGS} -O3 -g -DNDEBUG -mtune=native"

# GCC 4.8.5 does not support the following command:
export CXXFLAGS=${CXXFLAGS/-Wabi=2/}
